@@ -387,6 +387,7 @@ void GE_show_stored_msgs(GaimAccount*acct, const char* who, char** return_msg) {
                                      GAIM_MESSAGE_RECV, time((time_t)NULL));
                   gaim_conv_window_flash(gaim_conversation_get_window(conv));
                   g_free(*return_msg);
+                  *return_msg = 0;
                } else {
                   *return_msg = tmp_msg;
                }
@@ -1100,11 +1101,10 @@ static gboolean GE_plugin_load(GaimPlugin *h) {
 
    if (strcmp(gaim_core_get_version(), VERSION) != 0) {
       gaim_debug(GAIM_DEBUG_ERROR, "gaim-encryption",
-                 _("Compiled with '%s', running with '%s'."
-                   "  Gaim-Encryption will probably not run right.\n"),
+                 "Compiled with Gaim v'%s', running with v'%s'.\n"
                  VERSION, gaim_core_get_version());
-      GE_error_window(_("Gaim-Encryption plugin was compiled with a different "
-                        "version of Gaim.  You may experience problems."));
+      /* GE_error_window(_("Gaim-Encryption plugin was compiled with a different " */
+      /*                   "version of Gaim.  You may experience problems.")); */
    }
 
    init_prefs();
