@@ -17,6 +17,7 @@
 
 /* #define GAIM_PLUGINS */
 
+#include <glib/gstdio.h>
 #include <gdk/gdk.h>
 #include <gtk/gtk.h>
 #include <gtk/gtkplug.h>
@@ -284,7 +285,7 @@ static KeyCheckVal GE_check_known_key(const char* filename, key_ring_data* key)
    /* check file permissions */
    if (stat(path, &fs) == -1) {
       /* file doesn't exist, so make it */
-      fd = open(path, O_CREAT | O_EXCL, S_IRUSR | S_IWUSR);
+      fd = g_open(path, O_CREAT | O_EXCL, S_IRUSR | S_IWUSR);
       if (fd == -1) {
          /* Ok, maybe something else strange is going on... */
          gaim_debug(GAIM_DEBUG_ERROR, "gaim-encryption", "Error trying to create a known key file\n");
@@ -315,7 +316,7 @@ static KeyCheckVal GE_check_known_key(const char* filename, key_ring_data* key)
    /*   gaim_debug(GAIM_DEBUG_MISC, "gaim-encryption", "built line '%s'\n", line_str->str); */
 
    /* look for key in file */   
-   if( (fp = fopen(path, "r")) != NULL ) {
+   if( (fp = g_fopen(path, "r")) != NULL ) {
       while (!feof(fp)) {
          fgets(line, sizeof(line), fp);
          /* gaim_debug(GAIM_DEBUG_MISC, "gaim-encryption", "checking line '%s'\n", line); */
@@ -361,7 +362,7 @@ void GE_add_key_to_file(const char *filename, key_ring_data* key) {
    gaim_debug(GAIM_DEBUG_INFO, "gaim-encryption", "Saving key to file:%s:%p\n", key->name, key->account);
    g_snprintf(path, sizeof(path), "%s%s%s", gaim_user_dir(), G_DIR_SEPARATOR_S, filename);
 
-   fd = open(path, O_RDWR | O_CREAT, S_IRUSR | S_IWUSR);
+   fd = g_open(path, O_RDWR | O_CREAT, S_IRUSR | S_IWUSR);
    if (fd == -1) {
       gaim_debug(GAIM_DEBUG_ERROR, "gaim-encryption", "Error opening key file %s for write\n", path);
       /* WIN32 doesn't have user-based file permissions, so skips this */
@@ -375,7 +376,7 @@ void GE_add_key_to_file(const char *filename, key_ring_data* key) {
          return;
       }
 #endif
-      fd = open(path, O_RDWR | O_CREAT, S_IRUSR | S_IWUSR);
+      fd = g_open(path, O_RDWR | O_CREAT, S_IRUSR | S_IWUSR);
       if (fd == -1) {
          gaim_debug(GAIM_DEBUG_ERROR, "gaim-encryption", "Changed mode, but still wonky.  Aborting.\n");
          g_snprintf(errbuf, sizeof(errbuf),
@@ -418,7 +419,7 @@ void GE_add_key_to_file(const char *filename, key_ring_data* key) {
    if (feof(fp)) c = '\n';  /*if file is empty, we don't need to write a \n */
    fclose(fp);
    
-   fd = open(path, O_RDWR | O_CREAT, S_IRUSR | S_IWUSR);
+   fd = g_open(path, O_RDWR | O_CREAT, S_IRUSR | S_IWUSR);
    fp = fdopen(fd, "a+");
    fseek(fp, 0, SEEK_END);   /* should be unnecessary, but needed for WIN32 */
    
@@ -455,7 +456,7 @@ void GE_del_one_key_from_file(const char *filename, int key_num, const char *nam
    g_snprintf(path, sizeof(path), "%s%s%s", gaim_user_dir(), G_DIR_SEPARATOR_S, filename);
    
    /* Look for name in the file.  If it's not there, we're done */
-   fp = fopen(path, "r");
+   fp = g_fopen(path, "r");
 
    if (fp == NULL) {
       g_string_free(line_start, TRUE);
@@ -490,7 +491,7 @@ void GE_del_one_key_from_file(const char *filename, int key_num, const char *nam
    g_snprintf(tmp_path, sizeof(tmp_path), "%s.tmp", path);
    rename(path, tmp_path);
    
-   fd = open(path, O_RDWR | O_CREAT, S_IRUSR | S_IWUSR);
+   fd = g_open(path, O_RDWR | O_CREAT, S_IRUSR | S_IWUSR);
    if (fd == -1) {
       gaim_debug(GAIM_DEBUG_ERROR, "gaim-encryption", "Error opening key file %s\n", path);
       perror("Error opening key file");
@@ -502,7 +503,7 @@ void GE_del_one_key_from_file(const char *filename, int key_num, const char *nam
    }
    fp = fdopen(fd, "a+");
    
-   tmp_fp = fopen(tmp_path, "r");
+   tmp_fp = g_fopen(tmp_path, "r");
    if (tmp_fp == NULL) {
       gaim_debug(GAIM_DEBUG_ERROR, "gaim-encryption", "Wah!  I moved a file and now it is gone\n");
       fclose(fp);
@@ -557,7 +558,7 @@ void GE_del_key_from_file(const char *filename, const char *name, GaimAccount *a
    g_snprintf(path, sizeof(path), "%s%s%s", gaim_user_dir(), G_DIR_SEPARATOR_S, filename);
    
    /* Look for name in the file.  If it's not there, we're done */
-   fp = fopen(path, "r");
+   fp = g_fopen(path, "r");
 
    if (fp == NULL) {
       g_string_free(line_start, TRUE);
@@ -586,7 +587,7 @@ void GE_del_key_from_file(const char *filename, const char *name, GaimAccount *a
    g_snprintf(tmp_path, sizeof(tmp_path), "%s.tmp", path);
    rename(path, tmp_path);
    
-   fd = open(path, O_RDWR | O_CREAT, S_IRUSR | S_IWUSR);
+   fd = g_open(path, O_RDWR | O_CREAT, S_IRUSR | S_IWUSR);
    if (fd == -1) {
       gaim_debug(GAIM_DEBUG_ERROR, "gaim-encryption", "Error opening key file %s\n", path);
       perror("Error opening key file");
@@ -598,7 +599,7 @@ void GE_del_key_from_file(const char *filename, const char *name, GaimAccount *a
    }
    fp = fdopen(fd, "a+");
    
-   tmp_fp = fopen(tmp_path, "r");
+   tmp_fp = g_fopen(tmp_path, "r");
    if (tmp_fp == NULL) {
       gaim_debug(GAIM_DEBUG_ERROR, "gaim-encryption", "Wah!  I moved a file and now it is gone\n");
       fclose(fp);
@@ -637,7 +638,7 @@ key_ring * GE_load_keys(const char *filename) {
 
 
    g_snprintf(path, sizeof(path), "%s%s%s", gaim_user_dir(), G_DIR_SEPARATOR_S, filename);
-   if( (fp = fopen(path, "r")) != NULL ) {
+   if( (fp = g_fopen(path, "r")) != NULL ) {
       do {
       	 /* 7999 = MAX_KEY_STORLEN - 1 */
          rv = fscanf(fp, "%163s %9s %9s %7999s\n", nameacct, proto_name,
